jrnlsh.py
=========

This is a very simple stub shell that wraps the jrnl command to make using jrnl easier.

    jrnl> Just testing
    [Entry added to default journal]
    jrnl> This'll be awesome someday
    [Entry added to default journal]
    jrnl> I wonder if the \ character will work?
    [Entry added to default journal]
    jrnl> How about the & character?
    [Entry added to default journal]
    jrnl> Sweet...
    [Entry added to default journal]
    jrnl> list
    2021-09-08 09:20 Just testing

    2021-09-08 09:20 This'll be awesome someday

    2021-09-08 09:20 I wonder if the \ character will work?

    2021-09-08 09:21 How about the & character?

    2021-09-08 09:21 Sweet...

    jrnl>
